.. markovchain documentation master file, created by
   sphinx-quickstart on Fri Oct 13 21:46:09 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. toctree::
   :hidden:
   :maxdepth: 4

   source/modules

README
======

.. include:: ../README.rst
  :start-line: 3
